# WP data type

[![Upload Python Package To Pypi](https://github.com/QiYuTechOrg/wp_dt/actions/workflows/python-publish.yml/badge.svg)](https://github.com/QiYuTechOrg/wp_dt/actions/workflows/python-publish.yml)
[![Code Format Check](https://github.com/QiYuTechOrg/wp_dt/actions/workflows/code-format.yml/badge.svg)](https://github.com/QiYuTechOrg/wp_dt/actions/workflows/code-format.yml)

WP Data Type
